pub struct CanAddNotesEntry {
pub deck_name: String,
pub model_name: String,
pub fields: HashMap<String, String>,
pub tags: Vec<String>,
}Fields
deck_name: StringName of the deck where the note will be added.
model_name: StringName of the model inside the deck where the note will be added.
fields: HashMap<String, String>Fields available in the note.
The tags of the note.